@@ -324,7 +324,7 @@ class MainCoreGui:
                 self.activity_module = getattr(__import__('childsplay_sp.lib', \
                     globals(), locals(), [str(name)]), name)
             self.activity = self.activity_module.Activity(self.spgoodies)
-        except (ImportError, AttributeError), info:
+        except (utils.MyError, ImportError, AttributeError), info:
             self.logger.exception("Error importing activity %s" % name)
             # we must use a new renderer so that we leave the screen intact that
             # is used by the pygame sprite classes.
@@ -348,14 +348,14 @@ class MainCoreGui:
             self.activitylabel.rename(text, (CORE_BUTTONS_XCOORDS[1], 50))
             self.update_renderer()
             self.start_main_loop()
-    
+            
     def start_start(self):
         self.logger.debug("Calling activity start")
         self.levelcount = 0
         
         try:
             self.activity.start()
-        except StandardError, info:
+        except Exception, info:
             self.logger.exception("Error in %s start" % self.activity.get_name())
             raise utils.MyError, info
         if not self.dm.anonymous:
@@ -371,7 +371,8 @@ class MainCoreGui:
         It also displays a blocking 'Start' button."""
           
         self.logger.debug("Starting display_levelstart")
-
+        if self.cmd_options.no_text:
+            return
         org_screen = pygame.display.get_surface().convert()
         org_backgr = self.backgr.convert()
 
@@ -482,7 +483,7 @@ class MainCoreGui:
                 self.display_levelstart(self.levelcount)
                 # and call the post_next_level
                 self.activity.post_next_level()
-        except StandardError, info:
+        except utils.MyError, info:
             self.logger.exception("Error in %s next_level" % self.activity.get_name())
             raise utils.MyError, info
         # reset clipping
@@ -500,6 +501,7 @@ class MainCoreGui:
             c = 0
         if c == 0:
             self.logger.info("User wants exit")
+            print self.activity.get_name()
             if self.activity.get_name() != 'menu':
                 try:
                     self.activity_game_end()
@@ -623,7 +625,9 @@ class MainCoreGui:
                 self.mapper._get_end_time())
             self.mapper.insert('timespend', stime)
             # get the score value, if any and insert it into the dbase
-            self.mapper.insert('score', self.activity.get_score(stime))
+            sc = self.activity.get_score(stime)
+            self.logger.debug('got activity score: %s' % sc)
+            self.mapper.insert('score', sc)
             # You MUST call commit to write the contents of the mapper to disk.
             self.mapper.commit()
         # we try to stop any timers or execounter, just in case
@@ -777,7 +781,7 @@ class MainCoreGui:
     # the menu and start the choosen activity.
     # Then the start_main_loop is called by menu_activity_userchoice and the 
     # activity is started and the activity_loop is called. This will loop until
-    # the activity calls aone of the SPGoodies callbacks which will jump out the loop
+    # the activity calls one of the SPGoodies callbacks which will jump out the loop
     # and determine what's next. 
     def start_main_loop(self):
         self.levelcount = 0
@@ -872,6 +876,7 @@ class MainCoreGui:
                 try:
                     self.activity.loop(events)
                 except StandardError, info:
+                    self.activity.stop_timer()
                     self.logger.exception("%s raised an unhandled exception: %s traceback follows:" % \
                         (self.activity.get_name(), info))
                     self.activity_info_dialog(_("There was an error in %s. Please check the logs and inform the developers") % self.activity.get_name())
