@@ -45,11 +45,6 @@ module_logger = logging.getLogger("schoolsplay.SPSpriteUtils")
 # ocempgui is used to provide event awareness
 #from childsplay_sp.ocempgui.object import BaseObject
 
-class OneMatch:
-    """Used internally by the one_match method"""
-    onematch = False
-    havematch = False
-
 def SPInit(scr, back, group=pygame.sprite.Group()):
     """ Init(back,scr,group=pygame.sprite.Group()) -> SPGroup instance
         
@@ -117,9 +112,16 @@ class SPSprite(pygame.sprite.Sprite):
         # needed for rotation
         self.__dir = 0
         self.__OrgImage = self.image #comes from the derived class
+        # a group that owns by this sprite, used to address common properities
+        # of sprites within the group
+        self.group_owner = None
     
     def get_name(self):
         return self.__name
+
+    def set_group_owner(self, group):
+        """Set group that owns by this sprite"""
+        self.group_owner = group        
     
     def __eq__(self, x):
         return x == self.__name
@@ -160,16 +162,18 @@ class SPSprite(pygame.sprite.Sprite):
                 if self._event_type == MOUSEBUTTONDOWN and \
                     self.rect.contains((pygame.mouse.get_pos() + (0, 0))) or\
                         self._event_type == KEYDOWN:
-                # we check if we should call all possible matches
-                    if not OneMatch.onematch:
+                    # we check if we should call all possible matches
+                    if not (self.group_owner and self.group_owner.get_onematch()):
                         try:
                             cb = apply(self._callback, (self, event, self._args))
                         except StandardError, info:
                             self.logger.exception("Callback function %s failed" % self._callback)
                             self.logger.error(info)
                     else:
-                        if not OneMatch.havematch:
-                            OneMatch.havematch = True
+                        # we do not need to check existanse of self.group_owner because we get
+                        # here only if it exists.
+                        if not self.group_owner.get_havematch():
+                            self.group_owner.set_havematch(True)
                             try:
                                 cb = apply(self._callback, (self, event, self._args))
                             except StandardError, info:
@@ -290,8 +294,8 @@ class SPSprite(pygame.sprite.Sprite):
         It takes an optional argument 'pos' which will place the sprite to
         that location."""
         if pos:
-            #self.rect.topleft = pos
-            self.rect = self.rect.move(pos)
+            self.rect.topleft = pos
+            #self.rect = self.rect.move(pos)
         r = self.screen.blit(self.image, self.rect)
         pygame.display.update(r)
 
@@ -364,6 +368,8 @@ class SPGroup(pygame.sprite.RenderUpdates):
         pygame.sprite.RenderUpdates.__init__(self)
         self.scr = scr
         self.bck = bck
+        self.__onematch = False
+        self.__havematch = False 
         
     def refresh(self,  * args):
         """ Clear the sprites, calls the update method on the sprites,
@@ -390,7 +396,20 @@ class SPGroup(pygame.sprite.RenderUpdates):
         Anyway, use this if you want a real list of your sprites."""
         return [x for x in self.sprites()]
 
-    def one_match(self, onematch=False):
+    def add(self, *sprites):
+        """add a sprite to group
+
+        add(...) reuses pygame.sprite.RenderUpdates.add to add a sprite or
+        sequence of sprites to a group.
+        Before actual adding the sprite to the group, the linkage between the
+        sprite and the group is set"""
+        for sp in sprites:
+            if isinstance(sp, SPSprite):
+                if self.DEBUG: print >> sys.stderr, self.__class__, "a SPSrite added"
+                sp.set_group_owner(self)
+        pygame.sprite.RenderUpdates.add(self, *sprites)
+    
+    def set_onematch(self, onematch=False):
         """Manipulate the behaviour of the sprites to an event.
         
         When @onematch is true then the calling of callbacks stops after one
@@ -398,7 +417,28 @@ class SPGroup(pygame.sprite.RenderUpdates):
         and the user clicks on the top sprite, all the sprites below the top one 
         reacts to the event as if they were also clicked.
         By setting one_match only one sprite reacts and the rest is ignored."""
-        OneMatch.onematch = onematch
+        self.logger.debug("onematch is set to %s", onematch)
+        self.__onematch = onematch
+
+    def get_onematch(self):
+        self.logger.debug("onematch is %s", self.__onematch)
+        return self.__onematch
+
+    def set_havematch(self, havematch=False):
+        """Manipulates the flag which reflects whether the group of the sprites
+        has already handles an event
+        
+        If __onematch attribute of the group is set to true and a sprite within
+        the group triggers an event, it sets __havematch in true as so other
+        sprites in the group will not handle this event
+        The flag is used to re-set to false as soon as all sprites within the
+        group are updated with the event"""
+        self.logger.debug("havematch is set to %s", havematch)
+        self.__havematch = havematch
+
+    def get_havematch(self):
+        self.logger.debug("havematch is %s", self.__havematch)
+        return self.__havematch
 
     def update(self, * args):
         """update(...), this overrides the pygame.sprite.group.update
@@ -425,7 +465,8 @@ class SPGroup(pygame.sprite.RenderUpdates):
             for s in self.spritedict.keys():
                 s.update()
         # reset any match 
-        OneMatch.havematch = False
+        # do not use set_havematch here due to overhead - update() is invoked too often
+        self.__havematch = False
         return l
         
 class CPStackGroup:
