@@ -166,7 +166,7 @@ class ExitDialog(SPDialog):
             buttons = [nb, yb]
             results = [ocwc.DLGRESULT_CANCEL, ocwc.DLGRESULT_OK]
             
-        dlg = ocw.GenericDialog(_("Childsplay_sp question"), buttons, results)
+        dlg = ocw.GenericDialog(_("Question"), buttons, results)
         ltxt = _("Do you really want to quit ?")
         # we add spaces to force the dialog width otherwise the caption isn't displayed properly. 
         lbl = ocw.Label(ltxt + "           ")
@@ -188,7 +188,8 @@ class InfoDialog(SPDialog):
         @text may be a list with text strings or a ocemgui object.
         If the text string contains '\n' it's assumed the string is formatted in
         the correct length.
-        If no '\n' are found the string is formatted.""" 
+        If no '\n' are found the string is formatted.
+        You must call this dialog from within your eventloop.""" 
         module_logger.debug("InfoDialog called with %s" % text)
         SPDialog.__init__(self, re)
         yb = ocw.Button(_("Ok"))
@@ -197,7 +198,7 @@ class InfoDialog(SPDialog):
         yb.set_focus()
         buttons = [yb]
         results = [ocwc.DLGRESULT_OK]
-        dlg = ocw.GenericDialog(_("Childsplay_sp information"), buttons, results)
+        dlg = ocw.GenericDialog(_("Information"), buttons, results)
         if type(text) in (types.UnicodeType, types.StringType) or \
             type(text) is types.ListType:
             if type(text) is types.ListType:
@@ -240,7 +241,7 @@ class GraphDialog(SPDialog):
             sb.child.style["font"]["size"] = P_TTFSIZE
             buttons.append(sb)
         results = [ocwc.DLGRESULT_OK, savebutton]
-        dlg = ocw.GenericDialog(_("Childsplay_sp results diagram"), buttons, results)
+        dlg = ocw.GenericDialog(_("Results diagram"), buttons, results)
         dlg.content.add_child(surf)
         dlg.topleft = ((740-surf.width) / 2, (440-surf.height) / 2)
         dlg.connect_signal(ocwc.SIG_DIALOGRESPONSE, self._close, dlg, surf)
@@ -251,7 +252,7 @@ class GraphDialog(SPDialog):
 
 class Label:
     """Object that extends the Ocempgui Label"""
-    def __init__(self, re, text, pos):
+    def __init__(self, re, text, pos, theme='default'):
         """This will create a label with the @text and add it to the renderer.
         @re, reference to the renderer.
         @text, the text to display.
@@ -259,8 +260,13 @@ class Label:
         self.logger = logging.getLogger("schoolsplay.SPocwWidgets.Label")
         self._re = re
         self._frm = ocw.HFrame()
+        if theme == 'mpt':
+            self._frm.border = ocwc.BORDER_NONE
+        self._frm.create_style()['bgcolor'][ocwc.STATE_NORMAL] = DARK_GREY
         self.pos = pos
         lbl = ocw.Label(text)
+        if theme == 'mpt':
+            lbl.create_style()['bgcolor'][ocwc.STATE_NORMAL] = DARK_GREY
         lbl.set_align(ALIGN)
         lbl.create_style()
         lbl.style["font"]["size"] = P_TTFSIZE
@@ -268,6 +274,7 @@ class Label:
         self._frm.topleft = self.pos
         self._re.add_widget(self._frm)
         self._re.update() 
+        self.theme = theme
     
     def moveto(self, pos):
         """move the label, this will also call erase"""
@@ -281,9 +288,14 @@ class Label:
         self.logger.debug("rename called with: %s,%s" % (text, pos))
         self.erase()
         self._frm = ocw.HFrame()
+        if self.theme == 'mpt':
+            self._frm.border = ocwc.BORDER_NONE
+        self._frm.create_style()['bgcolor'][ocwc.STATE_NORMAL] = DARK_GREY
         lbl = ocw.Label(text)
         lbl.create_style()
         lbl.style["font"]["size"] = P_TTFSIZE
+        if self.theme == 'mpt':
+            lbl.create_style()['bgcolor'][ocwc.STATE_NORMAL] = DARK_GREY
         self._frm.add_child(lbl)
         self._frm.topleft = self.pos
         self._re.add_widget(self._frm)
