@@ -46,7 +46,7 @@ EXTRABORDER = 10
 # Add any new locales to this list.
 # For a supported language it's needed to have the pofile translated
 # aswell as localized soundfiles.
-SUPPORTED_LOCALES = ['en','nl','fr','it','ca', 'ru', 'es', 'de']
+SUPPORTED_LOCALES = ['en','nl','fr','it','ca', 'ru', 'es', 'de', 'pt_BR']
 
 # containers that can be used globally to store stuff
 class Img:
@@ -355,16 +355,22 @@ class Activity:
     
     def start(self):
         """Mandatory method."""
-        self.loc = self.SPG.get_localesetting()[0][:2]
-        self.logger.debug("Systems locale:%s" % self.loc)
-        if self.loc not in SUPPORTED_LOCALES:
-            self.logger.debug("systems locale not in SUPPORTED_LOCALES")
+        # horrible hacks to get it to work with extended locales
+        # This whole module must be redesigned for 2.0
+        
+        loc = self.SPG.get_localesetting()[0]
+        self.logger.debug("Systems locale:%s" % loc)
+        fnamesfull = os.path.join(self.my_datadir,'names',loc)
+        fnames = os.path.join(self.my_datadir,'names',loc[:2])
+        if os.path.exists(fnames):
+            self.loc = loc[:2]
+        elif os.path.exists(fnamesfull):
+            self.loc = loc
+        else:
             self.SPG.tellcore_info_dialog(_("Your language, %s, is not supported.\n I will now switch to English" % self.loc))
             self.loc = 'en'
-        elif not os.path.exists(os.path.join(self.my_datadir,'names',self.loc)):
-            self.logger.debug("'names' path %s does not exist" % os.path.join(self.my_datadir,'names',self.loc))
-            self.SPG.tellcore_info_dialog(_("Your language, %s, is supported but you must install\n the 'alphabet_sounds_%s' package.\n Look for it in your GNU/Linux distro or at www.schoolsplay.org.\n I will now switch to English" % (self.loc, self.loc)))
-            self.loc = 'en'
+        self.logger.debug("found {0}".format(self.loc))   
+
         self.initialsounddir = os.path.join(self.absdir,self.loc)
         self.crysounddir = os.path.join(self.my_datadir,'sounds')
         self.nameslist = os.path.join(self.my_datadir,'names',self.loc)
