@@ -123,12 +123,18 @@ class Activity:
         # list to hold the sprite objects.
         # we don't keep references to them as we query the sprites themself.
         self.imagelist = []
+        scaler = utils.ScaleImages(None,(136,136))
         # load all the images we need
         try:
             # load cardbacks and empty cards were we will blit our images on
-            self.cardback = utils.load_image(os.path.join(self.my_datadir,'cardback.png'),theme=self.theme)
+            self.cardback = scaler.get_images(\
+                utils.load_image(os.path.join(self.my_datadir,'cardback.png'),\
+                                theme=self.theme)\
+                                            )[0]
             # the rest of the images are turn into sprites in the start method
-            self.emptycard = utils.load_image(os.path.join(self.my_datadir,'cardfront.png'))
+            self.emptycard = scaler.get_images(\
+                utils.load_image(os.path.join(self.my_datadir,'cardfront.png'))\
+                                            )[0]
             if self.theme == 'cognitionplay':
                 imgdir = os.path.join(self.my_datadir,'cognitionplay')
             else:
@@ -247,22 +253,36 @@ class Activity:
             scaler = utils.ScaleImages(None,(scalesize,scalesize))
             # we also need a scaled cardback
             scaledcardback = scaler.get_images(image=self.cardback)[0]
+            # and a emptycard
+            emptycard = scaler.get_images(image=self.emptycard)[0]
             for img,file in cards:
+                cimg = emptycard.convert()
                 # scale the open card image
                 scaledimg = scaler.get_images(image=img)[0]
+                ix, iy = scaledimg.get_size()
+                cix, ciy = cimg.get_size()
+                x = (cix - ix) / 2
+                y = 0
+                cimg.blit(scaledimg,(x, y))
                 # No need to create lookup tables we just use
                 # the sprite callback framework to pass objects around.
                 # See the Card class how you can use the SPSprite objects and how
                 # these objects can act on events.
                 # Card connects itself to a MOUSEBUTTONDOWN event.
-                cardbacksprite = Card(scaledcardback,scaledimg,name=file)
+                cardbacksprite = Card(scaledcardback,cimg,name=file)
                 # we must add the sprite to the actives group, we call this group in the
                 # eventloop
                 self.actives.add(cardbacksprite)
         else:
             # We don't scale, logic is the same as above.
             for img,file in cards:
-                cardbacksprite = Card(self.cardback,img,name=file)
+                cimg = self.emptycard.convert()
+                ix, iy = img.get_size()
+                cix, ciy = cimg.get_size()
+                x = (cix - ix) / 2
+                y = 0
+                cimg.blit(img,(x, y))
+                cardbacksprite = Card(self.cardback,cimg,name=file)
                 self.actives.add(cardbacksprite)
         if scalesize > 136:
             step = 140
@@ -281,6 +301,7 @@ class Activity:
                 sprite = spritelist.pop()
                 Global.selected_cards[sprite] = 0
                 sprite.display_sprite((start_x+(x*step),start_y+(y*step)))
+        print cimg,self.cardback 
         pygame.display.update()
         return True
     
