@@ -364,6 +364,8 @@ class SidePanel:
         self.wrongimg = pygame.transform.scale(Img.pac_sad,(12,12))
         self.gooditems = 0
         self.count,self.level = 0,0
+
+        self.switch_task()
                
     def _set_last_level(self,pos):
         self._set_level("Level "+str(4)+":", 4)
@@ -374,20 +376,22 @@ class SidePanel:
                              antialias=True, bold=True)
         self.surf.blit(levelimg,pos)
                              
-    def goto_next_level(self):
-        self.count = 4
-    
     def set_word(self,word):
-        if self.count == 4:
-            self.level += 1
-            self.y = self.inlevel_word_pos_list[self.level][1]
-            self.count = 0
-        self.count += 1
         wordimg, size = font2surf(word,self.fsize-2,self.fcol,self.ttf,sizel=True,\
                                    antialias=True, bold=True)
         self.y += size[1]
         self.surf.blit(wordimg,(self.x,self.y))
             
+    def switch_task(self):
+        SwitchLevel = False
+        if self.count == 3:
+            self.level += 1
+            self.y = self.inlevel_word_pos_list[self.level][1]
+            self.count = 0
+            SwitchLevel = True
+        self.count += 1
+        return SwitchLevel
+    
     def set_good_wrong(self,gw):
         if gw > 2:
             self.surf.blit(self.wrongimg,(self.x-16,self.y+4))
@@ -402,7 +406,6 @@ class SidePanel:
         #print 'gooditems',self.gooditems
         if self.gooditems >= self.when:
             self.when = 0
-            self._set_last_level()
             return 1
         else:
             return 0
@@ -410,8 +413,8 @@ class SidePanel:
 class LastLevelImg:
     def __init__(self,music,img,pos):
         self.char = 'FRUIT' # to be compatible with the letters class in the loop
-        self.file = os.path.join(Img.libdir,'PackidData',music)
-        self.img = load_image(os.path.join(Img.libdir,'PackidData',img),1)
+        self.file = os.path.join(Img.datadir,music)
+        self.img = load_image(os.path.join(Img.datadir,img),1)
         self.pos = pos
         self.rect = self.img.get_rect()
         # calculate the pix pos row*24+60, col*24+150
@@ -509,6 +512,8 @@ class Activity:
         Snd.bummer = load_sound(os.path.join(self.CPsounddir,'bummer.wav'))
         Snd.eat = load_sound(os.path.join(self.my_datadir,'eat.wav'))
         
+        Img.datadir = self.my_datadir
+
         Img.pac_u = load_image(os.path.join(self.my_datadir,'pac_u.png'),1)
         Img.pac_u_c = load_image(os.path.join(self.my_datadir,'pac_u_c.png'),1)
         Img.pac_d = load_image(os.path.join(self.my_datadir,'pac_d.png'),1)
@@ -593,12 +598,10 @@ class Activity:
             self.brick = load_image(os.path.join(self.my_datadir,'leafs.png'),0)
             matrix = self._read_grid('grid1.txt')
             self._build_field(matrix,1)
-            self.sidepan.goto_next_level()
         elif self.level == 3:
             self.brick = load_image(os.path.join(self.my_datadir,'sea.png'),0)
             matrix = self._read_grid('grid2.txt')
             self._build_field(matrix,1)
-            self.sidepan.goto_next_level()
         elif self.level == 4:
             if self.sidepan.get_level_score():
                 load_music(os.path.join(self.my_datadir,'feelgood.ogg')).play()
@@ -613,7 +616,7 @@ class Activity:
             else:
                 text = _("The last level is only available when you finish the first three levels without errors.")
                 self.SPG.tellcore_info_dialog(text)
-                self.SPG.tellcore_game_end()
+                self.SPG.tellcore_game_end(store_db=True)
                 return
         else:
             self.stopflag = 1
@@ -643,7 +646,7 @@ class Activity:
         self.gw = 0 #good/wrong counter
         if self.level == 4:
             self.word = ''
-            self.letter_objs = []
+            self.objs_to_move,self.letter_objs = [],[]
             for obj in self.fruits:
                 pygame.display.update(self.screen.blit(obj.img,obj.rect))
                 self.letter_objs.append((obj))
@@ -811,7 +814,10 @@ class Activity:
                 self.sidepan.set_good_wrong(self.gw)
                 self._update_sidepanel()   
                 pygame.time.wait(2000)
-                self.next_exercise() 
+                if self.sidepan.switch_task():
+                    self.SPG.tellcore_level_end(store_db=True)
+                else:
+                    self.next_exercise() 
         else:
             #wrong letter
             if self.packid.img is Img.pac_sad:
@@ -860,7 +866,7 @@ class Activity:
             self._move_objs()
         
         elif self.pack_pos in self.letters_spots: # Have we hit a letter?
-            if self.level == 3 and self.pack_pos == (15,23):# pac hit exit in last level
+            if self.level == 4 and self.pack_pos == (15,23):# pac hit exit in last level
                 self.SPG.tellcore_game_end(True)
             else:
                 for item in self.letter_objs:
