@@ -114,7 +114,7 @@ def get_locale():
         if lang == '':
             lang = locale.getdefaultlocale()[0].split('_')[0]
     except Exception, info:
-        module_logger.error("%s, %s" % info, "Switching to English")
+        module_logger.error("%s, %s" % (info, "Switching to English"))
         lang = 'en'
     if lang == 'C' or lang.lower() == 'posix':
         # Default to English
@@ -202,6 +202,10 @@ class NoneSound:
         pass
     def queue(self):
         pass
+    def get_volume(self):
+        return None
+    def set_volume(sefl, sound_value):
+        pass
     def __eq__(self, other):
         if other == 'NoneSound': return True
         else: return False
@@ -236,15 +240,22 @@ def load_alphabetsound(char, loc='en'):
     fails the fallback 'en' is used.
     """
     name = ascii2hex(char)
-    if not os.path.exists(os.path.join(ALPHABETDIR, loc)) and '_' in loc:
-        if os.path.exists(os.path.join(ALPHABETDIR, loc.split('_')[0])):
-            loc = loc.split('_')[0]
+    module_logger.debug("load_alphabetsound got locale %s" % loc)
+    if not os.path.exists(os.path.join(ALPHABETDIR, loc)):
+        module_logger.debug("load_alphabetsound cannot find %s" % os.path.join(ALPHABETDIR, loc))
+        if '_' in loc:
+            module_logger.debug("load_alphabetsound trying to use short name for locale")
+            if os.path.exists(os.path.join(ALPHABETDIR, loc.split('_')[0])):
+                loc = loc.split('_')[0]
+            else:
+                loc = 'en'
         else:
             loc = 'en'
-    else:
-        loc = 'en'
     path = os.path.join(ALPHABETDIR, loc, name + '.ogg')
     module_logger.debug("load_alphabetsound trying to load %s" % path)
+    if not os.path.exists(path):
+        module_logger.debug("load_alphabetsound trying to use sound file name in upper case")
+        path = os.path.join(ALPHABETDIR, loc, name.upper() + '.ogg')
     snd = load_sound(path)
     return snd
     
@@ -692,15 +703,15 @@ class ScaleImages:
             # in case of error, we don't use a card back
             # just return scaled images.
             border = 10 # border size of card (memory), 2 * border size
-        try: 
-                self.stdCard = stdCardObj
-                # scale the card also to TargetSize, so we use one card for everything
-                self.scaled_card = self._scale_if_needed(self.stdCard)
-                self.TargetSize.inflate_ip(-border, -border)# reduce the size of the rect, so the images are smaller
-                    # then the card (compensate for border)
-        except StandardError, info:
-                self.logger.error("Failed to scale stdCardObj: %s" % info)
-                self.stdCard = None
+            try: 
+                    self.stdCard = stdCardObj
+                    # scale the card also to TargetSize, so we use one card for everything
+                    self.scaled_card = self._scale_if_needed(self.stdCard)
+                    self.TargetSize.inflate_ip(-border, -border)# reduce the size of the rect, so the images are smaller
+                        # then the card (compensate for border)
+            except StandardError, info:
+                    self.logger.exception("Failed to scale stdCardObj:%s, %s" % (stdCardObj, info))
+                    self.stdCard = None
         else:
             self.stdCard = None #to use as a test later, if we gonna blit the img on a card or not
                 # see get_images
@@ -1013,6 +1024,7 @@ def _set_lock(timeout=10):
         try:
             f = open(LOCKFILE, 'r')
             lines = f.readlines()
+            f.close()
             t = float(lines[0][:-1])
         except (IOError, TypeError):
             module_logger.exception("failed to read master lockfile")
@@ -1045,9 +1057,9 @@ def _remove_lock():
     if os.path.exists(LOCKFILE):
         try:
             os.remove(LOCKFILE)
-        except IOError:
-            module_logger.exception("failed to remove master lockfile")
-            module_logger.error("Please remove lock file: % manually" % LOCKFILE)
+        except (OSError, IOError), info:
+            module_logger.exception("failed to remove master lockfile: %s" % info)
+            module_logger.error("Please remove lock file: %s manually" % LOCKFILE)
     
 def Zscore(s_list, mean, sd):
     """Returns the zscores in a list with the coresponding dates
